@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: /sd/opensource/trunk/Audio-Scan/libid3tag/latin1.c 52786 2009-04-07T15:38:04.236288Z andy  $
+ * $Id: /sd/opensource/trunk/Audio-Scan/libid3tag/latin1.c 59610 2009-10-17T01:38:41.390924Z andy  $
  */
 
 # ifdef HAVE_CONFIG_H
@@ -73,7 +73,7 @@ id3_latin1_t *id3_latin1_duplicate(id3_latin1_t const *src)
   id3_latin1_t *latin1;
 
 #ifdef _MSC_VER
-  Newx(latin1, id3_latin1_size(src), id3_latin1_t);
+  New(0, latin1, id3_latin1_size(src), id3_latin1_t);
 #else
   latin1 = malloc(id3_latin1_size(src) * sizeof(*latin1));
 #endif
@@ -92,7 +92,7 @@ id3_ucs4_t *id3_latin1_ucs4duplicate(id3_latin1_t const *latin1)
   id3_ucs4_t *ucs4;
 
 #ifdef _MSC_VER
-  Newx(ucs4, id3_latin1_length(latin1) + 1, id3_ucs4_t);
+  New(0, ucs4, id3_latin1_length(latin1) + 1, id3_ucs4_t);
 #else
   ucs4 = malloc((id3_latin1_length(latin1) + 1) * sizeof(*ucs4));
 #endif
@@ -206,7 +206,7 @@ id3_ucs4_t *id3_latin1_deserialize(id3_byte_t const **ptr, id3_length_t length)
   end = *ptr + length;
 
 #ifdef _MSC_VER
-  Newx(latin1, (length + 1), id3_latin1_t);
+  New(0, latin1, (length + 1), id3_latin1_t);
 #else
   latin1 = malloc((length + 1) * sizeof(*latin1));
 #endif
@@ -220,7 +220,7 @@ id3_ucs4_t *id3_latin1_deserialize(id3_byte_t const **ptr, id3_length_t length)
   *latin1ptr = 0;
 
 #ifdef _MSC_VER
-  Newx(ucs4, id3_latin1_length(latin1) + 1, id3_ucs4_t);
+  New(0, ucs4, id3_latin1_length(latin1) + 1, id3_ucs4_t);
 #else
   ucs4 = malloc((id3_latin1_length(latin1) + 1) * sizeof(*ucs4));
 #endif
